// (C) Copyright 2015 Moodle Pty Ltd.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { RouterModule, Routes } from '@angular/router';
import { IonicModule } from '@ionic/angular';
import { TranslateModule } from '@ngx-translate/core';

import { CoreComponentsModule } from '@components/components.module';
import { CoreDirectivesModule } from '@directives/directives.module';

import { CoreSettingsAboutPage } from './about.page';

const routes: Routes = [
    {
        path: '',
        component: CoreSettingsAboutPage,
    },
    {
        path: 'deviceinfo',
        loadChildren: () =>
            import('@core/settings/pages/deviceinfo/deviceinfo.page.module')
                .then(m => m.CoreSettingsDeviceInfoPageModule),
    },
    {
        path: 'licenses',
        loadChildren: () =>
            import('@core/settings/pages/licenses/licenses.page.module')
                .then(m => m.CoreSettingsLicensesPageModule),
    },
];

@NgModule({
    imports: [
        RouterModule.forChild(routes),
        CommonModule,
        IonicModule,
        TranslateModule.forChild(),
        CoreComponentsModule,
        CoreDirectivesModule,
    ],
    declarations: [
        CoreSettingsAboutPage,
    ],
    exports: [RouterModule],
})
export class CoreSettingsAboutPageModule {}
